@@ -5,32 +5,6 @@
 # shellcheck source=scripts/core/sxmo_common.sh
 . sxmo_common.sh
 
-free_mutex() {
-	sxmo_mutex.sh can_suspend free "Playing with leds"
-	exit
-}
-
-ensure_mutex() {
-	sxmo_mutex.sh can_suspend lock "Playing with leds"
-	trap 'free_mutex' TERM INT
-}
-
-get_type() {
-	# Get type from variable name created dynamically from the color,
-	# e.g. $SXMO_LED_RED_TYPE
-	eval type='$'SXMO_LED_"$(echo "$1" | tr '[:lower:]' '[:upper:]')"_TYPE
-
-	# Defaults
-	if [ -z "$type" ]; then
-		case $1 in
-			red|green|blue) type="indicator" ;;
-			white) type="flash" ;;
-		esac
-	fi
-
-	printf %s "$type"
-}
-
 get_led() {
 	color="$1"
 
@@ -40,10 +14,9 @@ get_led() {
 	}
 	[ $# -lt 1 ] && usage
 
-	type="$(get_type "$color")";
-
-	value="$(cat "/sys/class/leds/$color:$type/brightness")"
-	max="$(cat "/sys/class/leds/$color:$type/max_brightness")"
+	# need brightnessctl release after 0.5.1 to have --percentage
+	value="$(brightnessctl -d "$color:*" get)"
+	max="$(brightnessctl -d "$color:*" max)"
 	printf "scale=0; %s / %s * 100\n" "$value" "$max" | bc -l
 }
 
@@ -57,16 +30,7 @@ set_led() {
 	color="$1"
 	percent="$2"
 
-	type="$(get_type "$color")";
-
-	if [ ! -d "/sys/class/leds/$color:$type" ]; then
-		echo "LED does not exist: /sys/class/leds/$color:$type"
-		exit 1
-	fi
-
-	max="$(cat "/sys/class/leds/$color:$type/max_brightness")"
-	brightness="$(echo "($percent / 100.0) * $max" | bc -l)"
-	printf "%0.f\n" "$brightness" > "/sys/class/leds/$color:$type/brightness"
+	brightnessctl -q -d "$color:*" set "$percent%"
 }
 
 set_leds() {
@@ -78,12 +42,21 @@ set_leds() {
 	wait
 }
 
-blink_led() {
+finish_blinking() {
+	sxmo_wakelock.sh unlock sxmo_playing_with_leds
+	eval set_leds green '$'old_green blue '$'old_blue red '$'old_red ${white:+white '$'old_white}
+	exit
+}
+
+blink_leds() {
 	for color in green blue red white; do
 		percent="$(get_led "$color")"
 		eval "old_$color=$percent" # store old value
 	done
 
+	sxmo_wakelock.sh lock sxmo_playing_with_leds 2s
+	trap 'finish_blinking' TERM INT EXIT
+
 	while [ -n "$1" ]; do
 		case "$1" in
 			green|blue|red|white)
@@ -105,23 +78,21 @@ blink_led() {
 	set_leds green 0 blue 0 red 0 ${white:+white 0}
 
 	sleep 0.1 # Make blink noticable
-
-	eval set_leds green '$'old_green blue '$'old_blue red '$'old_red ${white:+white '$'old_white}
 }
 
 [ -z "$SXMO_DISABLE_LEDS" ] || exit 1
 
+exec 3<> "${XDG_RUNTIME_DIR:-$HOME}/sxmo.led.lock"
+
 cmd="$1"
 shift
 case "$cmd" in
-	"set")
-		ensure_mutex
-		set_leds "$@"
-		free_mutex
+	"set"|blink)
+		flock -x 3
+		"$cmd"_leds "$@"
 		;;
-	get|blink)
-		ensure_mutex
-		"$cmd"_led "$@"
-		free_mutex
+	get)
+		flock -s 3
+		get_led "$@"
 		;;
 esac
