@@ -1,8 +1,10 @@
 #!/bin/sh
+# SPDX-License-Identifier: AGPL-3.0-only
+# Copyright 2022 Sxmo Contributors
 
 # include common definitions
 # shellcheck source=scripts/core/sxmo_common.sh
-. "$(dirname "$0")/sxmo_common.sh"
+. sxmo_common.sh
 
 # Takes 4 args:
 # (1) the filepath of the notification to write (or random to generate a random id)
@@ -28,7 +30,4 @@ writenotification() {
 
 [ "$#" -lt 4 ] && echo "Need >=4 args to create a notification" && exit 1
 writenotification
-
-if sxmo_screenlock.sh getCurState | grep -q off; then
-	sxmo_screenlock.sh lock
-fi
+sxmo_hook_statusbar.sh notifications
