@@ -1,5 +1,5 @@
 #!/bin/sh
-# configversion: 01e36247aaf22c514fd8932113f77142
+# configversion: 0a2402a485244d818a413065a1c82b4f
 # SPDX-License-Identifier: AGPL-3.0-only
 # Copyright 2022 Sxmo Contributors
 
@@ -20,7 +20,7 @@ superd_service_isrunning() {
 }
 
 sxmo_service_isrunning() {
-	sxmo_daemons.sh running "$1" > /dev/null
+	sxmo_jobs.sh running "$1" > /dev/null
 }
 
 if [ -z "$XPROPOUT" ]; then
@@ -75,7 +75,7 @@ case "$WMCLASS" in
 			$icon_cfg Gestures $(
 				superd_service_isrunning "sxmo_hook_lisgd" &&
 				printf "%s" "$icon_ton" || printf "%s" "$icon_tof"
-			) ^ 1 ^ supertoggle_daemon 'sxmo_hook_lisgd'
+			) ^ 1 ^ supertoggle_daemon 'sxmo_hook_lisgd' && (rm $XDG_CACHE_HOME/sxmo/sxmo.nogesture 2>/dev/null || touch $XDG_CACHE_HOME/sxmo/sxmo.nogesture)
 			$icon_cfg Toggle Bar ^ 0 ^ sxmo_wm.sh togglebar
 			$icon_bth Bluetooth $(
 				rfkill list bluetooth | grep -q "yes" &&
@@ -86,21 +86,25 @@ case "$WMCLASS" in
 			$icon_clk Change Timezone            ^ 1 ^ sxmo_timezonechange.sh
 			$icon_zzz Auto-suspend $(
 				[ -e "$XDG_CACHE_HOME"/sxmo/sxmo.nosuspend ] && printf "%s" "$icon_tof" || printf "%s" "$icon_ton"
-			) ^ 1 ^ (rm $XDG_CACHE_HOME/sxmo/sxmo.nosuspend || touch $XDG_CACHE_HOME/sxmo/sxmo.nosuspend)
+			) ^ 1 ^ (rm $XDG_CACHE_HOME/sxmo/sxmo.nosuspend 2>/dev/null || touch $XDG_CACHE_HOME/sxmo/sxmo.nosuspend)
 			$icon_zzz Auto-screen-off $(
 				[ -e "$XDG_CACHE_HOME/sxmo/sxmo.noidle" ] && printf "%s" "$icon_tof" || printf "%s" "$icon_ton"
-			) ^ 1 ^ (rm $XDG_CACHE_HOME/sxmo/sxmo.noidle || touch $XDG_CACHE_HOME/sxmo/sxmo.noidle) && sxmo_hook_unlock.sh
+			) ^ 1 ^ (rm $XDG_CACHE_HOME/sxmo/sxmo.noidle 2>/dev/null || touch $XDG_CACHE_HOME/sxmo/sxmo.noidle) && sxmo_state.sh set unlock
 			$icon_ror Autorotate $(
-				sxmo_daemons.sh running autorotate -q &&
+				sxmo_jobs.sh running autorotate -q &&
 				printf "%s" "$icon_ton" || printf "%s" "$icon_tof"
 			) ^ 1 ^ toggle_daemon 'Autorotate' autorotate sxmo_autorotate.sh
+			$([ -n "$SXMO_KEYBOARD_SLIDER_EVENT_DEVICE" ] && echo "$icon_ror Autorotate on Keyboard Open/Close $(
+				sxmo_jobs.sh running kb_autorotate -q &&
+				printf "%s" "$icon_ton" || printf "%s" "$icon_tof"
+			) ^ 1 ^ toggle_daemon 'Keyboard Autorotate' kb_autorotate sxmo_keyboard_autorotate.sh")
 			$icon_ror Rotate                     ^ 1 ^ sxmo_rotate.sh rotate
 			$icon_trm Hooks                      ^ 0 ^ sxmo_hookmenu.sh
 			$icon_upc Upgrade Pkgs               ^ 0 ^ sxmo_terminal.sh sxmo_upgrade.sh
 			$icon_sfl Migrate configuration      ^ 0 ^ sxmo_terminal.sh sxmo_migrate.sh
 			$icon_cfg Edit configuration         ^ 0 ^ sxmo_terminal.sh $EDITOR $XDG_CONFIG_HOME/sxmo/$(test "$SXMO_WM" = sway && printf sway || printf xinit)
 			$(command -v pmos-tweaks >/dev/null && echo "$icon_cfg PostmarketOS Tweaks	     ^ 0 ^ GDK_SCALE=1 pmos-tweaks")
-			$icon_cfg Suspend Blockers           ^ 0 ^ sxmo_terminal.sh sxmo_wakelock.sh debug watch
+			$icon_cfg Suspend Blockers           ^ 0 ^ sxmo_terminal.sh sxmo_debug_suspend.sh
 			$icon_inf Version                    ^ 0 ^ sxmo_terminal.sh sxmo_version.sh --block
 		"
 		WINNAME=Config
@@ -108,8 +112,8 @@ case "$WMCLASS" in
 	power)
 		# Power menu
 		CHOICES="
-			$icon_lck Lock               ^ 0 ^ sxmo_hook_lock.sh
-			$icon_lck Lock (Screen off)  ^ 0 ^ sxmo_hook_screenoff.sh
+			$icon_lck Lock               ^ 0 ^ sxmo_state.sh set lock
+			$icon_lck Lock (Screen off)  ^ 0 ^ sxmo_state.sh set screenoff
 			$icon_out Logout             ^ 0 ^ confirm Logout && sxmo_power.sh logout
 			$([ -f "$(xdg_data_path xsessions/sxmo.desktop)" ] &&
 				[ -f "$(xdg_data_path wayland-sessions/swmo.desktop)" ] &&
@@ -126,8 +130,8 @@ case "$WMCLASS" in
 			$icon_pau Pause        ^ 0 ^ sxmo_type -k Space
 			$icon_fbw Seek       ^ 1 ^ sxmo_type -k Left
 			$icon_ffw Seek       ^ 1 ^ sxmo_type -k Right
-			$icon_aru App Volume ↑ ^ 1 ^ sxmo_type 0
-			$icon_ard App Volume ↓ ^ 1 ^ sxmo_type 9
+			$icon_aru App Volume Up ^ 1 ^ sxmo_type 0
+			$icon_ard App Volume Down ^ 1 ^ sxmo_type 9
 			$icon_aru Speed up      ^ 1 ^ sxmo_type -k bracketRight
 			$icon_ard Speed down    ^ 1 ^ sxmo_type -k bracketLeft
 			$icon_cam Screenshot   ^ 1 ^ sxmo_type s
@@ -137,6 +141,14 @@ case "$WMCLASS" in
 		"
 		WINNAME=Mpv
 		;;
+	io.bassi.amberol)
+		CHOICES="
+			$icon_pau Play/Pause ^ 0 ^ playerctl play-pause
+			$icon_prv Previous Track ^ 1 ^ playerctl previous
+			$icon_nxt Next Track ^ 1 ^ playerctl next
+		"
+		WINNAME=Amberol
+		;;
 	*feh*)
 		# Feh
 		CHOICES="
@@ -204,7 +216,7 @@ case "$WMCLASS" in
 		"
 		WINNAME=St
 		;;
-	*foot*|*st*|*terminal*|org.gnome.vte.application)
+	*foot*|*st*|*terminal*|org.gnome.vte.application|*alacritty*)
 		# First we try to handle the app running inside the terminal:
 		WMNAME="${1:-$(printf %s "$XPROPOUT" | grep title: | cut -d" " -f2- | tr '[:upper:]' '[:lower:]')}"
 		if printf %s "$WMNAME" | grep -qi -E -w "(vi|vim|vis|nvim|neovim|kakoune)"; then
@@ -419,10 +431,10 @@ case "$WMCLASS" in
 						$icon_itm Type complete   ^ 0 ^ sxmo_type -M Ctrl -M Shift -k u
 						$icon_cpy Copy complete   ^ 0 ^ sxmo_type -M Ctrl -M Shift -k i
 						$icon_itm Selmode $(
-						  [ "$STSELMODEON" = 1 ] &&
-						  printf %b "$icon_ton" ||
-						  printf %b "$icon_tof"
-						  printf %b '^ 0 ^ sxmo_type -M Ctrl -M Shift -k s'
+							[ "$STSELMODEON" = 1 ] &&
+							printf %b "$icon_ton" ||
+							printf %b "$icon_tof"
+							printf %b '^ 0 ^ sxmo_type -M Ctrl -M Shift -k s'
 						)
 						$([ "$STSELMODEON" = 1 ] && echo 'Copy selection ^ 0 ^ sxmo_type -M Ctrl -M Shift -k c')
 						$icon_pst Paste           ^ 0 ^ sxmo_type -M Ctrl -M Shift -k v
@@ -456,6 +468,19 @@ case "$WMCLASS" in
 					CHOICES="$icon_kbd Hotkeys ^ 0 ^ sxmo_appmenu.sh sthotkeys"
 					WINNAME=Terminal
 					;;
+				*alacritty*)
+					CHOICES="
+						$icon_cpy Copy				^ 0 ^ sxmo_type -M Shift -M Ctrl c
+						$icon_pst Paste				^ 0 ^ sxmo_type -M Shift -M Ctrl v
+						$icon_vim VI Mode			^ 0 ^ sxmo_type -M Ctrl -M Shift -k Space
+						$icon_fnd Search Forward	^ 0 ^ sxmo_type -M Ctrl -M Shift -k f
+						$icon_fnd Search Backward	^ 0 ^ sxmo_type -M Ctrl -M Shift -k b
+						$icon_aru Search Previous   ^ 0 ^ sxmo_type -k Enter
+						$icon_ard Search Next		^ 0 ^ sxmo_type -M Shift -k Enter
+						$icon_kbd Hotkeys 			^ 0 ^ sxmo_appmenu.sh sthotkeys
+					"
+					WINNAME=Alacritty
+					;;
 			esac
 		fi
 	;;
@@ -586,6 +611,7 @@ case "$WMCLASS" in
 	*geopard*)
 		# Geopard
 		CHOICES="
+			$icon_flt Pipe URL          ^ 0 ^ sxmo_urlhandler.sh
 			$icon_pls New Tab            ^ 0 ^ sxmo_type -M Ctrl t
 			$icon_cls Close Tab          ^ 0 ^ sxmo_type -M Ctrl w
 			$icon_bok Open Bookmarks     ^ 0 ^ sxmo_type -M Ctrl b
@@ -615,6 +641,19 @@ case "$WMCLASS" in
 		"
 		WINNAME=Lagrange
 		;;
+	org.gnome.maps)
+	CHOICES="
+		$icon_gps Toggle Geoclue ^ 0 ^ superctl status geoclue-agent |grep started >/dev/null && superctl stop geoclue-agent || superctl start geoclue-agent
+		$icon_zmi Zoom in ^ 1 ^ sxmo_type -M ctrl =
+		$icon_zmo Zoom out ^ 1 ^ sxmo_type -M ctrl -k minus
+		$icon_fnd Explore POI ^ 0 ^ sxmo_type -M ctrl -M Shift F
+		$icon_fnd Search ^ 0 ^ sxmo_type -M ctrl f  && sxmo_keyboard.sh open
+		$icon_lst Show last results ^ 0 ^ sxmo_type -M ctrl r
+		$icon_map Toggle route planner ^ 0 ^ sxmo_type -M ctrl d
+		$icon_gps Show current location ^ 0 ^ sxmo_type -M ctrl l
+		"
+		WINNAME=Maps
+		;;
 	*mepo*)
 		# Mepo
 		# The choices / hotkeys for the contextmenu are generated through mepo's
@@ -659,6 +698,7 @@ case "$WMCLASS" in
 			$icon_net Networks                                           ^ 0 ^ sxmo_networks.sh
 			$icon_mus Audio                                              ^ 0 ^ sxmo_audio.sh
 			$icon_phn Modem                                              ^ 0 ^ sxmo_appmenu.sh modem
+			$icon_win Windows                                            ^ 0 ^ sxmo_wmmenu.sh
 			$icon_cfg Config                                             ^ 0 ^ sxmo_appmenu.sh config
 			$icon_pwr Power                                              ^ 0 ^ sxmo_appmenu.sh power
 		"
