@@ -1,5 +1,5 @@
 #!/bin/sh
-# configversion: ef09861c083e9642d0dffc2e436e307a
+# configversion: 666b1ee2211729d9d114adaf8eef041d
 # SPDX-License-Identifier: AGPL-3.0-only
 # Copyright 2022 Sxmo Contributors
 
@@ -28,11 +28,13 @@ set_state() {
 		return
 	fi
 
+	if sxmo_jobs.sh running proximity_lock; then
+		sxmobar -a -e bold -f orange state 90 "$icon_state_proximity" # circle with dot
+		return
+	fi
+
 	STATE_LABEL="$(cat "$SXMO_STATE")"
 	case "$STATE_LABEL" in
-		proximity*)
-			sxmobar -a -e bold -f orange state 90 "$icon_state_proximity" # circle with dot
-			;;
 		screenoff)
 			sxmobar -a -e bold -f red state 90 "$icon_state_screenoff" # filled circle
 			;;
@@ -227,8 +229,8 @@ set_wifi() {
 	fi
 
 	# if they have a vpn nmcli c shown --active should also list:
-	# tun0              ef5fcce9-fdae-4ffe-a540-b16fc7b42852  tun   tun0   
-	if printf %b "$CONN" | cut -d':' -f3 | grep -q ^tun$; then
+	# tun0              ef5fcce9-fdae-4ffe-a540-b16fc7b42852  tun   tun0
+	if printf %b "$CONN" | cut -d':' -f3 | grep -q -E "^tun$|^wireguard$"; then
 		wifivpn=1
 	else
 		wifivpn=0
@@ -272,90 +274,89 @@ set_wifi() {
 	sxmobar -a wifi-status 30 "$icon_wif"
 }
 
+# $1 = type (wifi, tun)
+# $2 = interface name (wlan0, tun0)
+set_ethernet() {
+	conname="$(nmcli -t device show "$2" | grep ^GENERAL.CONNECTION | cut -d: -f2-)"
+	if [ "$conname" = "--" ]; then
+		# not used device
+		sxmobar -d ethernet-status-"$2" 30
+		return
+	fi
+
+	if nmcli -t connection show "$conname" | grep ^ipv4.method | grep -q :shared; then
+		sxmobar -a ethernet-status-"$2" 30 "$icon_lnk"
+	else
+		sxmobar -d ethernet-status-"$2" 30
+	fi
+}
+
 # $1: type (reported by nmcli, e.g., wifi, tun)
 # $2: interface name (reported by nmcli, e.g., wlan0, tun0)
 set_network() {
 	case "$1" in
 		wifi|tun) set_wifi "$@" ;;
+		ethernet) set_ethernet "$@" ;;
 	esac
 }
 
 set_battery() {
-	count=0 # handle multiple batteries
-	for power_supply in /sys/class/power_supply/*; do
-		fgcolor=default
-		bgcolor=default
-		style=normal
-		BATCMP=
+	name="$1"
+	state="$2"
+	percentage="$3"
 
+	fgcolor=default
+	bgcolor=default
+	style=normal
+	BATCMP=
 
-		if [ "$(cat "$power_supply"/type)" = "Battery" ]; then
-			if [ -e "$power_supply"/capacity ]; then
-				PCT="$(cat "$power_supply"/capacity)"
-			elif [ -e "$power_supply"/charge_now ]; then
-				CHARGE_NOW="$(cat "$power_supply"/charge_now)"
-				CHARGE_FULL="$(cat "$power_supply"/charge_full_design)"
-				PCT="$(printf "scale=2; %s / %s * 100\n" "$CHARGE_NOW" "$CHARGE_FULL" | bc | cut -d'.' -f1)"
+	case "$state" in
+		fully-charged)
+				BATCMP="$icon_bat_c_3"
+				;;
+		charging)
+			if [ "$percentage" -lt 25 ]; then
+				BATCMP="$icon_bat_c_0"
+			elif [ "$percentage" -lt 50 ]; then
+				BATCMP="$icon_bat_c_1"
+			elif [ "$percentage" -lt 75 ]; then
+				BATCMP="$icon_bat_c_2"
 			else
-				continue
+				# Treat 'Full' status as same as 'fully-charged'
+				BATCMP="$icon_bat_c_3"
 			fi
-
-			count=$((count+1))
-
-			if [ -e "$power_supply"/status ]; then
-				# The status is not always given for the battery device.
-				# (sometimes it's linked to the charger device).
-				BATSTATUS="$(cut -c1 "$power_supply"/status)"
-			fi
-
-			# fixes a bug with keyboard case where
-			# /sys/class/power_supply/ip5xxx-charger/capacity
-			# exists but returns 'Not a tty'
-			if [ -z "$PCT" ]; then
-				BATCMP="ERR"
-			elif [ "$BATSTATUS" = "C" ] || [ "$BATSTATUS" = "F" ]; then
-				if [ "$PCT" -lt 25 ]; then
-					BATCMP="$icon_bat_c_0"
-				elif [ "$PCT" -lt 50 ]; then
-					BATCMP="$icon_bat_c_1"
-				elif [ "$PCT" -lt 75 ]; then
-					BATCMP="$icon_bat_c_2"
-				else
-					# Treat 'Full' status as same as 'Charging'
-					BATCMP="$icon_bat_c_3"
-				fi
-			else
-				if [ "$PCT" -lt 25 ]; then
-					fgcolor=red
-					if [ "$PCT" -lt 5 ]; then
-						BATCMP="$icon_bat_0"
-					elif [ "$PCT" -lt 10 ]; then
-						BATCMP="$icon_bat_1"
-					elif [ "$PCT" -lt 15 ]; then
-						BATCMP="$icon_bat_2"
-					else
-						BATCMP="$icon_bat_3"
-					fi
-				elif [ "$PCT" -lt 50 ]; then
-					fgcolor=orange
+			;;
+		discharging)
+			if [ "$percentage" -lt 25 ]; then
+				fgcolor=red
+				if [ "$percentage" -lt 5 ]; then
+					BATCMP="$icon_bat_0"
+				elif [ "$percentage" -lt 10 ]; then
 					BATCMP="$icon_bat_1"
-				elif [ "$PCT" -lt 75 ]; then
+				elif [ "$percentage" -lt 15 ]; then
 					BATCMP="$icon_bat_2"
 				else
 					BATCMP="$icon_bat_3"
 				fi
-			fi
-
-			sxmobar -a -t "$style" -b "$bgcolor" -f "$fgcolor" \
-				battery-icon 40 "$BATCMP"
-
-			if [ -z "$SXMO_BAR_SHOW_BAT_PER" ]; then
-				 sxmobar -d battery-status
+			elif [ "$percentage" -lt 50 ]; then
+				fgcolor=orange
+				BATCMP="$icon_bat_1"
+			elif [ "$percentage" -lt 75 ]; then
+				BATCMP="$icon_bat_2"
 			else
-				 sxmobar -a battery-status 41 "$PCT%"
+				BATCMP="$icon_bat_3"
 			fi
-		fi
-	done
+			;;
+	esac
+
+	sxmobar -a -t "$style" -b "$bgcolor" -f "$fgcolor" \
+		"battery-icon-$name" 40 "$BATCMP"
+
+	if [ -z "$SXMO_BAR_SHOW_BAT_PER" ]; then
+		sxmobar -d "battery-status-$name"
+	else
+		sxmobar -a "battery-status-$name" 41 "$percentage%"
+	fi
 }
 
 set_notifications() {
@@ -371,51 +372,48 @@ set_notifications() {
 set_volume() {
 	VOLCMP=""
 
-	if sxmo_modemaudio.sh is_call_audio_mode; then
-		if sxmo_modemaudio.sh is_muted_mic; then
-			VOLCMP="$icon_mmc"
-		else
-			VOLCMP="$icon_mic"
-		fi
-		if sxmo_modemaudio.sh is_enabled_speaker; then
-			VOLCMP="$VOLCMP $icon_spk"
-		else
-			VOLCMP="$VOLCMP $icon_ear"
-		fi
-		sxmobar -a -f green volume 50 "$VOLCMP"
-		return;
-	fi
-
 	if sxmo_audio.sh mic ismuted; then
 		VOLCMP="$icon_mmc"
 	else
-		VOLCMP="$icon_mic"
+		case "$(sxmo_audio.sh device getinput 2>/dev/null)" in
+			*Headset*)
+				VOLCMP="$icon_hst"
+				;;
+			*)
+				VOLCMP="$icon_mic"
+				;;
+		esac
 	fi
 
-	case "$(sxmo_audio.sh device get 2>/dev/null)" in
-		Speaker|"")
-			# nothing for default or pulse devices
-			;;
-		Headphones|Headphone)
-			VOLCMP="$VOLCMP $icon_hdp"
-			;;
-		Earpiece)
-			VOLCMP="$VOLCMP $icon_ear"
-			;;
-	esac
-
-	VOL="$(sxmo_audio.sh vol get)"
-	if [ -z "$VOL" ] || [ "$VOL" = "muted" ]; then
+	if sxmo_audio.sh vol ismuted; then
 		VOLCMP="$VOLCMP $icon_mut"
-	elif [ "$VOL" -gt 66 ]; then
-		VOLCMP="$VOLCMP $icon_spk"
-	elif [ "$VOL" -gt 33 ]; then
-		VOLCMP="$VOLCMP $icon_spm"
-	elif [ "$VOL" -ge 0 ]; then
-		VOLCMP="$VOLCMP $icon_spl"
+	else
+		case "$(sxmo_audio.sh device get 2>/dev/null)" in
+			*Speaker*|"")
+				# nothing for default or pulse devices
+				;;
+			*Headphone*)
+				VOLCMP="$VOLCMP $icon_hdp"
+				;;
+			*Earpiece*)
+				VOLCMP="$VOLCMP $icon_ear"
+				;;
+		esac
+		VOL="$(sxmo_audio.sh vol get)"
+		if [ "$VOL" -gt 66 ]; then
+			VOLCMP="$VOLCMP $icon_spk"
+		elif [ "$VOL" -gt 33 ]; then
+			VOLCMP="$VOLCMP $icon_spm"
+		elif [ "$VOL" -ge 0 ]; then
+			VOLCMP="$VOLCMP $icon_spl"
+		fi
 	fi
 
-	sxmobar -a volume 50 "$VOLCMP"
+	if sxmo_modemaudio.sh is_call_audio_mode; then
+		sxmobar -a -f green volume 50 "$VOLCMP"
+	else
+		sxmobar -a volume 50 "$VOLCMP"
+	fi
 }
 
 sxmo_debug "$@"
@@ -424,22 +422,30 @@ case "$1" in
 		shift
 		set_network "$@"
 		;;
-	time|modem|battery|volume|state|notifications)
+	battery)
+		shift
+		set_battery "$@"
+		;;
+	time|modem|volume|state|notifications)
 		set_"$1"
 		;;
 	periodics|state_change) # 55 s loop and screenlock triggers
 		set_time
-		set_modem
-		set_battery
+		if [ -z "$SXMO_NO_MODEM" ]; then
+			set_modem
+		fi
 		set_state
 		set_network wifi wlan0
 		;;
 	all)
 		sxmobar -r
 		set_time
-		set_modem
-		set_battery
-		set_volume
+		if [ -z "$SXMO_NO_MODEM" ]; then
+			set_modem
+		fi
+		if [ -z "$SXMO_NO_AUDIO" ]; then
+			set_volume
+		fi
 		set_state
 		set_notifications
 		set_network wifi wlan0
@@ -448,4 +454,3 @@ case "$1" in
 		exit # swallow it !
 		;;
 esac
-
